<?php

namespace App\Http\Controllers\Back;

use App\Models\Admin;
use App\Models\AdminRole;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules\Password;

class UtilisateurController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:admin');
    }

    public function index()
    {
        $bread = "Utilisateur";
        $data = Admin::with('roles')->get();
        return view('back.utilisateur.index', compact('bread', 'data'));
    }

    public function updateEtat(Request $request)
    {
        Admin::where('id', $request->id)->update([
            'etat' => $request->etat
        ]);

        return json_encode([
            "message" => "success",
            "etat" => $request->etat
        ]);
    }

    public function delete(Request $request)
    {
        Admin::where('id', $request->id)->delete();
        return json_encode([
            "message" => "success"
        ]);
    }

    public function add()
    {
        $bread = "Utilisateur";
        $role = AdminRole::where('etat', 1)->get();
        return view('back.utilisateur.add', compact('bread', 'role'));
    }

    public function edit($id)
    {
        $bread = "Utilisateur";
        $role = AdminRole::where('etat', 1)->get();
        $data = Admin::find($id);
        return view('back.utilisateur.edit', compact('bread', 'role', 'data'));
    }

    public function save(Request $request)
    {
        $request->validate([
            'nom' => 'required',
            'prenom' => 'required',
            'email' => 'required|email|unique:admins',
            'password' => 'required|min:8|confirmed',
            'password_confirmation' => 'required|same:password|min:8',
            'role_id' => 'required',
        ], [
            'nom.required' => 'Nom requis',
            'prenom.required' => 'Prenom requis',
            'email.required' => 'Email requis',
            'unique' => 'Email deja utilisé',
            'password.required' => 'Mot de passe requis',
            'password_confirmation.required' => 'Confirmation du mot de passe requis',
            'role_id.required' => 'Rôle requis',
            'password.confirmed' => 'Le mot de passe n\'est pas identique',
            'password.min' => 'Votre mot de passe doit comporter au moins 8 caractères',
            'password_confirmation.same' => 'Le mot de passe confirmé n\'est pas identique',
            'password_confirmation.min' => 'Votre mot de passe doit comporter au moins 8 caractères',
        ]);

        $data = new Admin();
        $data->nom = $request->nom;
        $data->prenom = $request->prenom;
        $data->email = $request->email;
        $data->password = Hash::make($request->password);
        $data->role_id = $request->role_id;
        $data->save();

        return redirect()->route('list.user')->with('status', 'Utilisateur bien sauvegarder');
    }

    public function update(Request $request)
    {
        $data = Admin::find($request->id);

        if ($request->password == null) {
            request()->request->remove('password');
        }

        $request->validate([
            'nom' => 'required',
            'prenom' => 'required',
            'email' => 'required|email|unique:admins,email,' . $request->id,
            'password' => 'sometimes|min:8',
            'role_id' => 'required',
        ], [
            'nom.required' => 'Nom requis',
            'prenom.required' => 'Prenom requis',
            'email.required' => 'Email requis',
            'unique' => 'Email deja utilisé',
            'password.required' => 'Mot de passe requis',
            'password.min' => 'Votre mot de passe doit comporter au moins 8 caractères',
            'role_id.required' => 'Rôle requis'
        ]);

        if ($request->password != null) {
            $data->nom = $request->nom;
            $data->prenom = $request->prenom;
            $data->email = $request->email;
            $data->password = Hash::make($request->password);
            $data->role_id = $request->role_id;
        } else {
            $data->nom = $request->nom;
            $data->prenom = $request->prenom;
            $data->email = $request->email;
            $data->role_id = $request->role_id;
        }

        $data->save();

        if (Auth::guard('admin')->user()->id == $request->id && $request->password != null) {
            Auth::logout();
            \Session::flush();
            return redirect()->route('auth.admin.login')->with('status', 'Vous êtes bien deconnecté');
        } else {
            return redirect()->route('list.user')->with('status', 'Utilisateur bien mis à jour');
        }
    }
}
